@@ -26,20 +26,22 @@ This module contains classes and functions associated to the cost volume aggrega
 import logging
 import sys
 from abc import ABCMeta, abstractmethod
-from typing import Union
+from typing import Union, Dict
 
 import xarray as xr
 
 
-class AbstractAggregation():
+class AbstractAggregation:
     """
     Abstract Aggregation class
     """
+
     __metaclass__ = ABCMeta
 
-    aggreg_methods_avail = {}
+    aggreg_methods_avail: Dict = {}
+    cfg = None
 
-    def __new__(cls, **cfg: dict) -> object:
+    def __new__(cls, **cfg: dict):
         """
         Return the plugin associated with the aggregation_method given in the configuration
 
@@ -48,23 +50,31 @@ class AbstractAggregation():
         """
 
         if cls is AbstractAggregation:
-            if isinstance(cfg['aggregation_method'], str):
+            if isinstance(cfg["aggregation_method"], str):
                 try:
-                    return super(AbstractAggregation, cls).__new__(cls.aggreg_methods_avail[cfg['aggregation_method']])
+                    return super(AbstractAggregation, cls).__new__(cls.aggreg_methods_avail[cfg["aggregation_method"]])
                 except KeyError:
-                    logging.error('No aggregation method named % supported', cfg['aggregation_method'])
+                    logging.error(
+                        "No aggregation method named % supported",
+                        cfg["aggregation_method"],
+                    )
                     sys.exit(1)
             else:
-                if isinstance(cfg['aggregation_method'], unicode): # pylint: disable=undefined-variable
+                if isinstance(cfg["aggregation_method"], unicode):  # type: ignore # pylint: disable=undefined-variable
                     # creating a plugin from registered short name given as unicode (py2 & 3 compatibility)
                     try:
                         return super(AbstractAggregation, cls).__new__(
-                            cls.aggreg_methods_avail[cfg['aggregation_method'].encode('utf-8')])
+                            cls.aggreg_methods_avail[cfg["aggregation_method"].encode("utf-8")]
+                        )
                     except KeyError:
-                        logging.error('No aggregation method named % supported', cfg['aggregation_method'])
+                        logging.error(
+                            "No aggregation method named % supported",
+                            cfg["aggregation_method"],
+                        )
                         sys.exit(1)
         else:
             return super(AbstractAggregation, cls).__new__(cls)
+        return None
 
     @classmethod
     def register_subclass(cls, short_name: str):
@@ -93,11 +103,12 @@ class AbstractAggregation():
         Describes the aggregation method
 
         """
-        print('Aggregation description')
+        print("Aggregation description")
 
     @abstractmethod
-    def cost_volume_aggregation(self, img_left: xr.Dataset, img_right: xr.Dataset, cv: xr.Dataset,
-                                **cfg: Union[str, int]) -> None:
+    def cost_volume_aggregation(
+        self, img_left: xr.Dataset, img_right: xr.Dataset, cv: xr.Dataset, **cfg: Union[str, int]
+    ) -> None:
         """
         Aggregate the cost volume for a pair of images
 
