@@ -27,7 +27,6 @@ import logging
 import warnings
 from typing import List, Union, Tuple
 import sys
-import copy
 
 import numpy as np
 import rasterio
@@ -83,13 +82,15 @@ def read_img(img: str, no_data: float, mask: str = None, classif: str = None, se
 
     if np.isnan(no_data):
         no_data_pixels = np.where(np.isnan(data))
+    elif np.isinf(no_data):
+        no_data_pixels = np.where(np.isinf(data))
     else:
         no_data_pixels = np.where(data == no_data)
 
     # We accept nan values as no data on input image but to not disturb cost volume processing as stereo computation
     # step,nan as no_data must be converted. We choose -9999 (can be another value). No_data position aren't erased
     # because stored in 'msk'
-    if no_data_pixels[0].size != 0 and np.isnan(no_data):
+    if no_data_pixels[0].size != 0 and (np.isnan(no_data) or np.isinf(no_data)):
         data[no_data_pixels] = -9999
         no_data = -9999
 
@@ -97,11 +98,20 @@ def read_img(img: str, no_data: float, mask: str = None, classif: str = None, se
         {"im": (["row", "col"], data.astype(np.float32))},
         coords={"row": np.arange(data.shape[0]), "col": np.arange(data.shape[1])},
     )
+
+    transform = img_ds.profile["transform"]
+    crs = img_ds.profile["crs"]
+    # If the image has no geotransform, its transform is the identity matrix, which may not be compatible with QGIS
+    # To make it compatible, the attributes are set to None
+    if crs is None:
+        transform = None
+        crs = None
+
     # Add image conf to the image dataset
     dataset.attrs = {
         "no_data_img": no_data,
-        "crs": img_ds.profile["crs"],
-        "transform": img_ds.profile["transform"],
+        "crs": crs,
+        "transform": transform,
         "valid_pixels": 0,  # arbitrary default value
         "no_data_mask": 1,
     }  # arbitrary default value
@@ -157,16 +167,13 @@ def read_img(img: str, no_data: float, mask: str = None, classif: str = None, se
     return dataset
 
 
-def check_dataset(dataset: xr.Dataset) -> xr.Dataset:
+def check_dataset(dataset: xr.Dataset) -> None:
     """
     Check if input dataset is correct, and return the corresponding xarray.DataSet
 
     :param dataset: dataset
     :type dataset: xr.Dataset
-    :return: full dataset
-    :rtype: xarray.DataSet
     """
-    new_dataset = copy.copy(dataset)
 
     # Check image
     if "im" not in dataset:
@@ -204,8 +211,6 @@ def check_dataset(dataset: xr.Dataset) -> xr.Dataset:
         logging.error("User must provide image transform")
         sys.exit(1)
 
-    return new_dataset
-
 
 def prepare_pyramid(
     img_left: xr.Dataset, img_right: xr.Dataset, num_scales: int, scale_factor: int
