@@ -24,6 +24,7 @@
 This module contains class associated to the pandora state machine
 """
 
+import warnings
 import logging
 from typing import Dict, Union, List
 import numpy as np
@@ -44,8 +45,12 @@ from pandora import multiscale
 from pandora import optimization
 from pandora import refinement
 from pandora import matching_cost
-from pandora import validation
-from pandora import cost_volume_confidence
+
+# This silences numba's TBB threading layer warning
+with warnings.catch_warnings():
+    warnings.filterwarnings("ignore")
+    from pandora import validation
+    from pandora import cost_volume_confidence
 from .img_tools import prepare_pyramid
 
 
@@ -462,16 +467,23 @@ class PandoraMachine(Machine):  # pylint:disable=too-many-instance-attributes
             self.disp_min, self.disp_max = multiscale_.disparity_range(
                 self.left_disparity, self.dmin_user, self.dmax_user
             )
+            # Set to None the disparity map for the next scale
+            self.left_disparity = None
+
         else:
             self.disp_min, self.disp_max = multiscale_.disparity_range(
                 self.left_disparity, self.dmin_user, self.dmax_user
             )
+            # Set to None the disparity map for the next scale
+            self.left_disparity = None
+
             # Update min and max user disparity according to the current scale
             self.dmin_user_right = self.dmin_user_right * self.scale_factor
             self.dmax_user_right = self.dmax_user_right * self.scale_factor
             self.right_disp_min, self.right_disp_max = multiscale_.disparity_range(
                 self.right_disparity, self.dmin_user_right, self.dmax_user_right
             )
+            self.right_disparity = None
 
         # Get the next scale's images
         self.left_img = self.img_left_pyramid.pop(0)
